@@ -24,8 +24,8 @@ C     JAMES BUNCH, UNIV. CALIF. SAN DIEGO, ARGONNE NAT. LAB.
 c     **************************************************************************
 
       SUBROUTINE XDSIFA(A,LDA,N,KPVT,INFO)
-      INTEGER LDA,N,KPVT(1),INFO
-      DOUBLE PRECISION A(LDA,1)
+      INTEGER LDA,N,KPVT(*),INFO
+      DOUBLE PRECISION A(LDA,*)
 C
 C     XDSIFA FACTORS A DOUBLE PRECISION SYMMETRIC MATRIX BY ELIMINATION
 C     WITH SYMMETRIC PIVOTING.
@@ -247,8 +247,8 @@ C
       RETURN
       END
       SUBROUTINE XDSISL(A,LDA,N,KPVT,B)
-      INTEGER LDA,N,KPVT(1)
-      DOUBLE PRECISION A(LDA,1),B(1)
+      INTEGER LDA,N,KPVT(*)
+      DOUBLE PRECISION A(LDA,*),B(*)
 C
 C     XDSISL SOLVES THE DOUBLE PRECISION SYMMETRIC SYSTEM
 C     A * X = B
@@ -419,9 +419,9 @@ C
       END
       SUBROUTINE XDSIDI(A,LDA,N,KPVT,DET,INERT,WORK,JOB)
       INTEGER LDA,N,JOB
-      DOUBLE PRECISION A(LDA,1),WORK(1)
+      DOUBLE PRECISION A(LDA,*),WORK(*)
       DOUBLE PRECISION DET(2)
-      INTEGER KPVT(1),INERT(3)
+      INTEGER KPVT(*),INERT(3)
 C
 C     XDSIDI COMPUTES THE DETERMINANT, INERTIA AND INVERSE
 C     OF A DOUBLE PRECISION SYMMETRIC MATRIX USING THE FACTORS FROM
